@@ -1,7 +1,7 @@
 from requests import HTTPError
 
 
-class HTTPClientError(HTTPError):
+class ClientError(HTTPError):
     def __init__(
         self,
         response,
@@ -13,7 +13,7 @@ class HTTPClientError(HTTPError):
         self.code = response_json.get("code")
         self.message = response_json.get("message")
 
-        super(HTTPClientError, self).__init__(self.message)
+        super(ClientError, self).__init__(self.message)
 
     def __str__(self):
         return self.message
